summaryrefslogtreecommitdiffstats
path: root/kdeui/kbuttonbox.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-07 03:45:53 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-07 03:45:53 +0000
commit10308be19ef7fa44699562cc75946e7ea1fdf6b9 (patch)
tree4bc444c00a79e88105f2cfce5b6209994c413ca0 /kdeui/kbuttonbox.h
parent307136d8eef0ba133b78ceee8e901138d4c996a1 (diff)
downloadtdelibs-10308be19ef7fa44699562cc75946e7ea1fdf6b9.tar.gz
tdelibs-10308be19ef7fa44699562cc75946e7ea1fdf6b9.zip
Revert automated changes
Sorry guys, they are just not ready for prime time Work will continue as always git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdelibs@1212479 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kdeui/kbuttonbox.h')
-rw-r--r--kdeui/kbuttonbox.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/kdeui/kbuttonbox.h b/kdeui/kbuttonbox.h
index 0d4b36b67..7eda45577 100644
--- a/kdeui/kbuttonbox.h
+++ b/kdeui/kbuttonbox.h
@@ -30,9 +30,9 @@ class KButtonBoxPrivate;
/**
* Container widget for buttons.
*
* This class uses Qt tqlayout control to place the buttons; can handle
* both vertical and horizontal button placement. The default border
- * is now @p 0 (making it easier to deal with tqlayouts). The space
+ * is now @p 0 (making it easier to deal with layouts). The space
* between buttons is now more Motif compliant.
*
* @author Mario Weilguni <mweilguni@sime.com>
@@ -65,7 +65,7 @@ public:
* This size is
* calculated by the width/height of all buttons plus border/autoborder.
*/
- virtual TQSize tqsizeHint() const;
+ virtual TQSize sizeHint() const;
virtual TQSizePolicy sizePolicy() const;
virtual void resizeEvent(TQResizeEvent *);
@@ -146,9 +146,9 @@ public:
* This function must be called @em once after all buttons have been
* inserted.
*
* It will start tqlayout control.
*/
- void tqlayout();
+ void layout();
public: // as PrivateData needs Item, it has to be exported
class Item;
@@ -30,9 +30,9 @@ class KButtonBoxPrivate;
* Container widget for buttons.
*
- * This class uses Qt tqlayout control to place the buttons; can handle
+ * This class uses Qt layout control to place the buttons; can handle
* both vertical and horizontal button placement. The default border
@@ -146,9 +146,9 @@ public:
* inserted.
*
- * It will start tqlayout control.
+ * It will start layout control.
*/